#!/bin/bash

if [ -z "${1}" ]; then
	echo "Usage: ${0} <app_name>" >&2
	exit 1
fi

app_name=${1}
mnt_mode=${2}
app_home=/apps/${app_name}
app_fstb=${app_home}/etc/fstab

if [ ! -f "${app_fstb}" ]; then
	exit 0
fi

i=0
while read fstab_line; do

	let i="${i}+1"

	if [ $(expr match "${fstab_line}" "#") = "1" ]; then
		continue
	fi

	rem_path=$(echo -e "${fstab_line}" | cut -f1)
	loc_path=${app_home}/$(echo -e "${fstab_line}" | cut -f2)
	mnt_type=$(echo -e "${fstab_line}" | cut -f3)
	mnt_opts=$(echo -e "${fstab_line}" | cut -f4)

	if [ -z "${rem_path}" ] | [ -z "${loc_path}" ]; then
		echo "line ${i}: malformed line"
		continue
	fi

	if [ -z "${mnt_type}" ]; then
		echo "line ${i}: mount type not defined"
		continue
	fi

	if [ ! -d "${loc_path}" ]; then
		echo "line ${i}: mount path ${loc_path} does not exist"
		continue
	fi

	if [ "${mnt_mode}" = "u" ]; then
		/bin/umount ${loc_path}
	else

		case "${mnt_type}" in
			cifs)
				/sbin/insmod /usr/local/modules/nls_base.ko 2> /dev/null
				/sbin/insmod /usr/local/modules/cifs.ko 2> /dev/null
				;;
		esac

		if [ -z "${mnt_opts}" ]; then
			/bin/mount -t ${mnt_type} ${rem_path} ${loc_path}
		else
			/bin/mount -t ${mnt_type} ${rem_path} ${loc_path} -o ${mnt_opts}
		fi
	fi

done < ${app_fstb}
